# Surfy Ecosystem for Python

This repository contains all the libraries for successful working with Surfy Ecosystem in a Python environment.

![Surfy](https://github.com/surfy-one/core.py/blob/main/imgs/surfy.cover.jpg?raw=true "Surfy")


## Installation

```

pip3 install surfy

```